@@ -780,10 +780,6 @@ screen_saver_floater_do_draw (ScreenSaver        *screen_saver,
 	if (screen_saver->should_show_paths && (floater->path != NULL))
 	{
 		gdouble dash_pattern[] = { 5.0 };
-		gint size;
-
-		size = CLAMP ((int) (FLOATER_MAX_SIZE * floater->path_start_scale),
-		              FLOATER_MIN_SIZE, FLOATER_MAX_SIZE);
 
 		cairo_save (context);
 		cairo_set_source_rgba (context, 1.0, 1.0, 1.0, .2 * floater->opacity);
@@ -910,11 +906,15 @@ screen_saver_free (ScreenSaver *screen_saver)
 
 	g_hash_table_destroy (screen_saver->cached_sources);
 
-	if (screen_saver->state_update_timeout_id != 0)
+	if (screen_saver->state_update_timeout_id != 0) {
 		g_source_remove (screen_saver->state_update_timeout_id);
+		screen_saver->state_update_timeout_id = 0;
+	}
 
-	if (screen_saver->stats_update_timeout_id != 0)
+	if (screen_saver->stats_update_timeout_id != 0) {
 		g_source_remove (screen_saver->stats_update_timeout_id);
+		screen_saver->stats_update_timeout_id = 0;
+	}
 
 	screen_saver_destroy_floaters (screen_saver);
 
