@@ -100,10 +100,9 @@ gs_theme_window_init (GSThemeWindow *window)
 static void
 gs_theme_window_finalize (GObject *object)
 {
-	GSThemeWindow *window;
 	GObjectClass  *parent_class;
 
-	window = GS_THEME_WINDOW (object);
+	GS_THEME_WINDOW (object);
 
 	parent_class = G_OBJECT_CLASS (gs_theme_window_parent_class);
 
@@ -200,7 +199,11 @@ gs_theme_window_real_realize (GtkWidget *widget)
 		exit (1);
 	}
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+	gtk_widget_get_preferred_size (widget, &requisition, NULL);
+#else
 	gtk_widget_size_request (widget, &requisition);
+#endif
 	allocation.x = x;
 	allocation.y = y;
 	allocation.width = width;
