@@ -336,9 +336,7 @@ gste_popsquares_set_property (GObject            *object,
                               const GValue       *value,
                               GParamSpec         *pspec)
 {
-	GSTEPopsquares *self;
-
-	self = GSTE_POPSQUARES (object);
+	GSTE_POPSQUARES (object);
 
 	switch (prop_id)
 	{
@@ -354,9 +352,7 @@ gste_popsquares_get_property (GObject            *object,
                               GValue             *value,
                               GParamSpec         *pspec)
 {
-	GSTEPopsquares *self;
-
-	self = GSTE_POPSQUARES (object);
+	GSTE_POPSQUARES (object);
 
 	switch (prop_id)
 	{
@@ -557,7 +553,7 @@ draw_frame (GSTEPopsquares *pop,
 	int      border = 1;
 	gboolean twitch = FALSE;
 	int      x, y;
-	int      sw, sh, gw, gh;
+	int      gw, gh;
 	int      nsquares;
 	int      window_width;
 	int      window_height;
@@ -573,8 +569,6 @@ draw_frame (GSTEPopsquares *pop,
 	gs_theme_engine_get_window_size (GS_THEME_ENGINE (pop),
 	                                 &window_width,
 	                                 &window_height);
-	sw = window_width / pop->priv->subdivision;
-	sh = window_height / pop->priv->subdivision;
 
 	gw = pop->priv->subdivision;
 	gh = pop->priv->subdivision;
