@@ -41,12 +41,6 @@
 #include "gs-marshal.h"
 #include "gs-debug.h"
 
-/* this is for dbus < 0.3 */
-#if ((DBUS_VERSION_MAJOR == 0) && (DBUS_VERSION_MINOR < 30))
-#define dbus_bus_name_has_owner(connection, name, err)      dbus_bus_service_exists(connection, name, err)
-#define dbus_bus_request_name(connection, name, flags, err) dbus_bus_acquire_service(connection, name, flags, err)
-#endif
-
 static void              gs_listener_class_init         (GSListenerClass *klass);
 static void              gs_listener_init               (GSListener      *listener);
 static void              gs_listener_finalize           (GObject         *object);
@@ -899,6 +893,7 @@ listener_dbus_get_ref_entries (GSListener     *listener,
 	return DBUS_HANDLER_RESULT_HANDLED;
 }
 
+#ifdef WITH_CONSOLE_KIT
 static void
 listener_add_ck_ref_entry (GSListener     *listener,
                            int             entry_type,
@@ -932,6 +927,7 @@ listener_remove_ck_ref_entry (GSListener *listener,
 {
 	listener_remove_ref_entry (listener, entry_type, cookie);
 }
+#endif
 
 static DBusHandlerResult
 listener_dbus_add_ref_entry (GSListener     *listener,
@@ -1005,7 +1001,6 @@ listener_dbus_remove_ref_entry (GSListener     *listener,
 {
 	DBusMessage        *reply;
 	DBusError           error;
-	const char         *sender;
 	guint32             cookie;
 
 	dbus_error_init (&error);
@@ -1034,7 +1029,7 @@ listener_dbus_remove_ref_entry (GSListener     *listener,
 		g_error ("No memory");
 
 	/* FIXME: check sender is from same connection as entry */
-	sender = dbus_message_get_sender (message);
+	dbus_message_get_sender (message);
 
 	listener_remove_ref_entry (listener, entry_type, cookie);
 
