@@ -116,7 +116,7 @@ enum
     PROP_THROTTLED,
 };
 
-#define FADE_TIMEOUT 1000
+#define FADE_TIMEOUT 250
 
 static guint         signals [LAST_SIGNAL] = { 0, };
 
@@ -1842,7 +1842,7 @@ gs_manager_activate (GSManager *manager)
 	manager->priv->active = TRUE;
 
 	/* fade to black and show windows */
-	do_fade = TRUE;
+	do_fade = FALSE;
 	if (do_fade)
 	{
 		manager->priv->fading = TRUE;
