@@ -357,7 +357,6 @@ static void
 set_status (GSWatcher *watcher,
             guint      status)
 {
-	gboolean res;
 	gboolean is_idle;
 
 	if (! watcher->priv->active)
@@ -376,7 +375,7 @@ set_status (GSWatcher *watcher,
 
 	if (is_idle)
 	{
-		res = _gs_watcher_set_session_idle_notice (watcher, is_idle);
+		_gs_watcher_set_session_idle_notice (watcher, is_idle);
 		/* queue an activation */
 		if (watcher->priv->idle_id > 0)
 		{
@@ -392,9 +391,10 @@ set_status (GSWatcher *watcher,
 		if (watcher->priv->idle_id > 0)
 		{
 			g_source_remove (watcher->priv->idle_id);
+			watcher->priv->idle_id = 0;
 		}
-		res = _gs_watcher_set_session_idle (watcher, FALSE);
-		res = _gs_watcher_set_session_idle_notice (watcher, FALSE);
+		_gs_watcher_set_session_idle (watcher, FALSE);
+		_gs_watcher_set_session_idle_notice (watcher, FALSE);
 	}
 }
 
@@ -566,6 +566,7 @@ gs_watcher_finalize (GObject *object)
 	if (watcher->priv->idle_id > 0)
 	{
 		g_source_remove (watcher->priv->idle_id);
+		watcher->priv->idle_id = 0;
 	}
 
 	watcher->priv->active = FALSE;
