@@ -36,10 +36,10 @@
 
 #include <gio/gio.h>
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 #define MATE_DESKTOP_USE_UNSTABLE_API
 #include <libmate-desktop/mate-desktop-utils.h>
-#define gdk_spawn_command_line_on_screen mate_gdk_spawn_command_line_on_screen
+
+#if GTK_CHECK_VERSION (3, 0, 0)
 #include "gs-debug.h"
 #endif
 
@@ -420,7 +420,7 @@ response_cb (GtkWidget *widget,
 
 		error = NULL;
 
-		res = gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
+		res = mate_gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
 		                                        GPM_COMMAND,
 		                                        &error);
 		if (! res)
@@ -1212,7 +1212,11 @@ constrain_list_size (GtkWidget      *widget,
 	/* constrain height to be the tree height up to a max */
 	max_height = (gdk_screen_get_height (gtk_widget_get_screen (widget))) / 4;
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+	gtk_widget_get_preferred_size (to_size, &req, NULL);
+#else
 	gtk_widget_size_request (to_size, &req);
+#endif
 
 	requisition->height = MIN (req.height, max_height);
 }
@@ -1548,7 +1552,6 @@ init_capplet (void)
 	GtkWidget *fullscreen_preview_window;
 	GtkWidget *fullscreen_preview_previous;
 	GtkWidget *fullscreen_preview_next;
-	GtkWidget *fullscreen_preview_area;
 	GtkWidget *fullscreen_preview_close;
 	char      *gtk_builder_file;
 	gdouble    activate_delay;
@@ -1595,7 +1598,7 @@ init_capplet (void)
 	preview_button     = GTK_WIDGET (gtk_builder_get_object (builder, "preview_button"));
 	gpm_button         = GTK_WIDGET (gtk_builder_get_object (builder, "gpm_button"));
 	fullscreen_preview_window = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_window"));
-	fullscreen_preview_area = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_area"));
+	GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_area"));
 	fullscreen_preview_close = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_close"));
 	fullscreen_preview_previous = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_previous_button"));
 	fullscreen_preview_next = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_preview_next_button"));
